from typing import List, Optional

from pydantic import UUID4, AnyUrl, Field

from .commons import Id, RestrictedBaseModel


class Mapping(RestrictedBaseModel):
    empaia_id: UUID4 = Field(
        examples=["b10648a7-340d-43fc-a2d9-4d91cc86f33f"], description="EMPAIA ID generated by Medical Data Service"
    )
    mds_url: AnyUrl = Field(
        examples=["https://mds.example.org"],
        description="Base URL of Medical Data Service instance that generated empaia_id",
    )
    local_id: Id = Field(examples=["3a1e3715-8945-4c13-8fc6-9c1c549cf85d"], description="Local ID provided by AP-LIS")


class Mappings(RestrictedBaseModel):
    items: List[Mapping]


class MappingQuery(RestrictedBaseModel):
    empaia_ids: Optional[List[UUID4]] = Field(
        default=None,
        examples=[
            [
                "b10648a7-340d-43fc-a2d9-4d91cc86f33f",
                "b10648a7-340d-43fc-a2d9-4d91cc86f33f",
            ]
        ],
        description="Empaia IDs",
    )
